# MySQL creation commands for dad

CREATE DATABASE dad;
USE dad;

# MySQL privileges stuff for dad
GRANT select,insert,update,delete,alter,drop
  ON dad.*
  TO dad@localhost
  IDENTIFIED BY 'mom';
FLUSH PRIVILEGES;

#
# Table structure for table 'album'
#

CREATE TABLE album (
  album_id int(11) NOT NULL auto_increment,
  title char(100) NOT NULL default '',
  PRIMARY KEY  (album_id),
  UNIQUE KEY album_id (album_id)
) TYPE=MyISAM;

#
# Table structure for table 'albumxartist'
#

CREATE TABLE albumxartist (
  axu_id int(11) NOT NULL auto_increment,
  artist_id int(11) NOT NULL default '0',
  album_id int(11) NOT NULL default '0',
  PRIMARY KEY  (axu_id),
  UNIQUE KEY axu_id (axu_id)
) TYPE=MyISAM;

#
# Table structure for table 'artist'
#

CREATE TABLE artist (
  artist_id int(11) NOT NULL auto_increment,
  artistname varchar(255) NOT NULL default '',
  first_letter_id mediumint(4) NOT NULL default '0',
  PRIMARY KEY  (artist_id),
  UNIQUE KEY artist_id (artist_id)
) TYPE=MyISAM;

#
# Table structure for table 'asso'
#

CREATE TABLE asso (
  artist_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  parent int(11) NOT NULL default '0',
   UNIQUE KEY artist_id (artist_id,user_id,parent)
) TYPE=MyISAM;

#
# Table structure for table 'asso_song'
#

CREATE TABLE asso_song (
  audio_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  parent int(11) NOT NULL default '0',
  UNIQUE KEY audio_id (audio_id,user_id,parent)
) TYPE=MyISAM;

#
# Table structure for table 'audio'
#

CREATE TABLE audio (
  audio_id int(11) NOT NULL auto_increment,
  audiofile_id int(11) NOT NULL default '0',
  audio_type_id smallint(4) NOT NULL default '0',
  user_last int(11) NOT NULL default '0',
  title varchar(255) NOT NULL default '',
  album_id int(11) NOT NULL default '0',
  track tinyint(3) NOT NULL default '0',
  checked tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (audio_id),
  UNIQUE KEY audio_id (audio_id)
) TYPE=MyISAM;

#
# Table structure for table 'audiofile'
#

CREATE TABLE audiofile (
  audiofile_id int(11) NOT NULL auto_increment,
  audiofile_type_id smallint(4) NOT NULL default '0',
  path_id smallint(4) NOT NULL default '0',
  filename char(255) NOT NULL default '',
  filesize char(12) NOT NULL default '',
  checksum char(255) NOT NULL default '0',
  length float NOT NULL default '0',
  mix_in float NOT NULL default '0',
  mix_out float NOT NULL default '0',
  rms int(11) NOT NULL default '0',
  intro float NOT NULL default '0',
  outro float NOT NULL default '0',
  user_in int(11) NOT NULL default '0',
  last_played timestamp(14) NOT NULL,
  PRIMARY KEY  (audiofile_id),
  UNIQUE KEY audiofile_id (audiofile_id)
) TYPE=MyISAM;

#
# Table structure for table 'audiofiletype'
#

CREATE TABLE audiofiletype (
  audiofile_type_id smallint(4) NOT NULL auto_increment,
  filetype char(100) NOT NULL default '',
  PRIMARY KEY  (audiofile_type_id),
  UNIQUE KEY audiofile_type_id (audiofile_type_id)
) TYPE=MyISAM;

INSERT INTO audiofiletype VALUES (1,'mp3');
INSERT INTO audiofiletype VALUES (2,'ogg');

#
# Table structure for table 'audiotype'
#

CREATE TABLE audiotype (
  audio_type_id smallint(4) NOT NULL auto_increment,
  audiotype char(100) NOT NULL default '',
  PRIMARY KEY  (audio_type_id),
  UNIQUE KEY audio_type_id (audio_type_id)
) TYPE=MyISAM;

INSERT INTO audiotype VALUES (1,'song');
INSERT INTO audiotype VALUES (2,'jingle');
INSERT INTO audiotype VALUES (3,'publicity');

#
# Table structure for table 'audioxartist'
#

CREATE TABLE audioxartist (
  axu_id int(11) NOT NULL auto_increment,
  artist_id int(11) NOT NULL default '0',
  audio_id int(11) NOT NULL default '0',
  PRIMARY KEY  (axu_id),
  UNIQUE KEY axu_id (axu_id)
) TYPE=MyISAM;

#
# Table structure for table `audioxgroup`
#

CREATE TABLE audioxgroup (
  audio_id int(11) NOT NULL default '0',
  audio_group_id int(11) NOT NULL default '0'
) TYPE=MyISAM;

#
# Table structure for table 'category'
#

CREATE TABLE category (
  cat_id int(11) NOT NULL auto_increment,
  description varchar(255) NOT NULL default '',
  PRIMARY KEY  (cat_id),
  UNIQUE KEY cat_id (cat_id)
) TYPE=MyISAM;

#
# Table structure for table `dad_version`
#

CREATE TABLE dad_version (
  version_number varchar(20) NOT NULL default ''
) TYPE=MyISAM;

#
# Dumping data for table `dad_version`
#

INSERT INTO dad_version VALUES ('0.2.5');

#
# Table structure for table 'firstletter'
#

CREATE TABLE firstletter (
  first_letter_id mediumint(4) NOT NULL auto_increment,
  letter char(1) NOT NULL default '',
  PRIMARY KEY  (first_letter_id),
  UNIQUE KEY first_letter_id (first_letter_id)
) TYPE=MyISAM;

#
# Table structure for table 'last_playlist'
#

CREATE TABLE last_playlist (
  audio_id int(11) NOT NULL default '0',
  artist_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  lastorder int(11) NOT NULL default '0'
) TYPE=MyISAM;

#
# Table structure for table 'path'
#

CREATE TABLE paths (
  path_id int(11) NOT NULL auto_increment,
  path varchar(255) NOT NULL default '',
  PRIMARY KEY  (path_id),
  UNIQUE KEY path_id (path_id)
) TYPE=MyISAM;

#
# Table structure for table `save_playlist`
#

CREATE TABLE save_playlist (
  audio_id int(11) NOT NULL default '0',
  artist_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  saveorder int(11) NOT NULL default '0',
  playlistname varchar(255) NOT NULL default '',
  playlist_id int(11) NOT NULL default '0'
) TYPE=MyISAM;

#
# Table structure for table 'score'
#

CREATE TABLE score (
  audio_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  cat_id int(11) NOT NULL default '0',
  rate float NOT NULL default '0'
) TYPE=MyISAM;

#
# Table structure for table 'temp_playlist'
#

CREATE TABLE temp_playlist (
  audio_id int(11) NOT NULL default '0',
  artist_id int(11) NOT NULL default '0',
  user_id int(11) NOT NULL default '0',
  temporder int(11) NOT NULL default '0'
) TYPE=MyISAM;

#
# Table structure for table 'unrated'
#

CREATE TABLE unrated (
  audio_id int(11) NOT NULL default '0',
  cat_id int(11) NOT NULL default '0',
  user_id smallint(4) NOT NULL default '0',
  KEY audio_id (audio_id),
  KEY cat_id (cat_id),
  KEY user_id (user_id)
) TYPE=MyISAM;

#
# Table structure for table 'user'
#

CREATE TABLE users (
  user_id int(11) NOT NULL auto_increment,
  username char(20) NOT NULL default '',
  password char(30) NOT NULL default '',
  first_name char(50) NOT NULL default '',
  last_name char(50) NOT NULL default '',
  level tinyint(1) NOT NULL default '0',
  mount varchar(50) NOT NULL default '0',
  system tinyint(1) NOT NULL default '0',
  PRIMARY KEY  (user_id),
  UNIQUE KEY user_id (user_id)
) TYPE=MyISAM;

INSERT INTO users VALUES (1, 'dad', '7a632ee326bdc1c7', 'Dave', 'Dina', 1, '/opt/davedina/music', 1);

    


